@@ -86,7 +86,7 @@
 #define KITEMMODELS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMMODELS_NO_DEPRECATED
-#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
+#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
 #endif
 #ifdef KITEMMODELS_NO_DEPRECATED_WARNINGS
 #  define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x54a00
+#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x54b00
 #  endif
 #endif
 
